@@ -29,5 +29,7 @@ CLASSPATH=".:$INSTALL_DIR/lib/*:$INSTALL_DIR/a3files:$A3FILES:$CLASSPATH"
 export CLASSPATH
 PATH="$INSTALL_DIR/Java/jdk/bin:$INSTALL_DIR/Java/jre/bin:$PATH"
 export PATH
+LD_LIBRARY_PATH="$INSTALL_DIR/natives/linux-amd64"
+export LD_LIBRARY_PATH
 
 bash
