@@ -63,6 +63,11 @@ public class A23 {
             //されたら以下の一行を削除するべし．
             System.setProperty("j3d.viewFrustumCulling","false");
             //***** 2014,11/01追加ここまで *****//
+            //***** 2019,01/18追加ここから *****//
+            //一部のWindowsなPCで，起動に1分以上かかるという
+            //不具合があるのでい以下の一行を入れてみる．
+            System.setProperty("jogamp.gluegen.UseTempJarCache","false");
+            //***** 2019,01/18追加ここまで *****//
             isInitialized = true;
         }
     }
