@@ -6,6 +6,7 @@ import java.awt.event.KeyListener;
 import javax.vecmath.*;
 import java.io.*;
 import javax.media.j3d.*;
+import java.util.ArrayList;
 
 /**
  * A3CanvasとJA3Canvasを統一的に扱うために
@@ -486,7 +487,46 @@ public interface A3CanvasInterface {
      */
     public void rollCameraLeftNow(double deg,int scene);
 
+    /**
+     * 方向ベクトルのX,Y,Z成分を指定して，カメラがそちらを向くように回転します。
+     */
+    public void turnCameraTo(double dirX,double dirY,double dirZ);
 
+    /**
+     * 方向ベクトルを指定して，カメラがそちらを向くように回転します。
+     */
+    public void turnCameraTo(Vector3d dir);
+
+    /**
+     * 方向ベクトルのX,Y,Z成分を指定して，カメラがそちらを向くように即時に回転します。
+     */
+    public void turnCameraToNow(double dirX,double dirY,double dirZ);
+
+    /**
+     * 方向ベクトルを指定して，カメラがそちらを向くように即時に回転します。
+     */
+    public void turnCameraToNow(Vector3d dir);
+
+    /**
+     * 方向ベクトルのX,Y,Z成分とシーンを指定して，カメラがそちらを向くように回転します。
+     */
+    public void turnCameraTo(double dirX,double dirY,double dirZ,int scene);
+
+    /**
+     * 方向ベクトルとシーンを指定して，カメラがそちらを向くように回転します。
+     */
+    public void turnCameraTo(Vector3d dir,int scene);
+
+    /**
+     * 方向ベクトルのX,Y,Z成分とシーンを指定して，カメラがそちらを向くように即時に回転します。
+     */
+    public void turnCameraToNow(double dirX,double dirY,double dirZ,int scene);
+
+    /**
+     * 方向ベクトルとシーンを指定して，カメラがそちらを向くように即時に回転します。
+     */
+    public void turnCameraToNow(Vector3d dir,int scene);
+    
 
 
 
@@ -760,6 +800,18 @@ public interface A3CanvasInterface {
      */
     public void setCameraLookAtPointImmediately(double x,double y,double z,Vector3d up);
 
+    /**
+     * 対象となるオブジェクトをルックアットポイントとしてカメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(A3Object a);
+
+    /**
+     * 対象となるオブジェクトをルックアットポイントとし、上方向ベクトルを使ってカメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(A3Object a,Vector3d up);
+
     /**
      * ヘッドライトのON,OFFを設定します。
      */
@@ -1326,6 +1378,18 @@ public interface A3CanvasInterface {
      */
     public void setCameraLookAtPointImmediately(double x,double y,double z,Vector3d up,int scene);
 
+    /**
+     * シーンを指定し、対象となるオブジェクトをルックアットポイントとしてカメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(A3Object a,int scene);
+
+    /**
+     * シーンを指定し、対象となるオブジェクトをルックアットポイントとし、上方向ベクトルを使ってカメラの回転を
+     * 指定します。
+     */
+    public void setCameraLookAtPoint(A3Object a,Vector3d up,int scene);
+
     /**
      * シーンを指定して、ナビゲーションモードを指定します。
      * 必要であればナビゲーションの初期化に必要なパラメータも渡してやります。
@@ -1798,6 +1862,18 @@ public interface A3CanvasInterface {
      */
     public void setCameraLookAtPointNow(double x,double y,double z,Vector3d up);
 
+    /**
+     * 対象となるオブジェクトをルックアットポイントとしてカメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointNow(A3Object a);
+
+    /**
+     * 対象となるオブジェクトをルックアットポイントとし、上方向ベクトルを使ってカメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointNow(A3Object a,Vector3d up);
+
     /**
      * シーンを指定して、カメラの位置を即時に指定します。
      */
@@ -1920,4 +1996,178 @@ public interface A3CanvasInterface {
      * 即時に指定します。
      */
     public void setCameraLookAtPointNow(double x,double y,double z,Vector3d up,int scene);
+
+    /**
+     * シーンを指定し、対象となるオブジェクトをルックアットポイントとしてカメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointNow(A3Object a,int scene);
+
+    /**
+     * シーンを指定し、対象となるオブジェクトをルックアットポイントとし、上方向ベクトルを使ってカメラの回転を
+     * 即時に指定します。
+     */
+    public void setCameraLookAtPointNow(A3Object a,Vector3d up,int scene);
+//****************************************
+    /**
+     * addされている全てのA3Objectを返します．
+     */
+    public ArrayList<A3Object> getAll();
+
+    /**
+     * addされているA3Objectの中で引数で指定されているClassまたは
+     * そのサブクラスのインスタンスのみを返します．
+     */
+    public ArrayList<A3Object> getAll(Class<? extends A3Object> c);
+
+    /**
+     * シーンを指定し、addされている全てのA3Objectを返します．
+     */
+    public ArrayList<A3Object> getAll(int scene);
+
+    /**
+     * シーンを指定し、addされているA3Objectの中で引数で指定されているClassまたは
+     * そのサブクラスのインスタンスのみを返します．
+     */
+    public ArrayList<A3Object> getAll(Class<? extends A3Object> c,int scene);
+    /*
+    //ここより下のメソッドは上のgetAllメソッドとUtilのユーティリティ
+    //メソッドで実現できるようにしよう(2015,06/15)
+    public A3Object getNearest(Vector3d v);
+    public A3Object getNearest(double x,double y,double z);
+    public A3Object getNearest(Vector3d v,Class<? extends A3Object> c);
+    public A3Object getNearest(double x,double y,double z,Class<? extends A3Object> c);
+    public ArrayList<A3Object> getNeighborhood(Vector3d v,double r);
+    public ArrayList<A3Object> getNeighborhood(double x,double y,double z,double r);
+    public ArrayList<A3Object> getNeighborhood(Vector3d v,double r,Class<? extends A3Object> c);
+    public ArrayList<A3Object> getNeighborhood(double x,double y,double z,double r,Class<? extends A3Object> c);
+    public ArrayList<A3Object> getObjectsInFrustum(Frustum f);
+    public ArrayList<A3Object> getObjectsInFrustum(Frustum f,,Class<? extends A3Object> c);
+    //----------------------------------------
+    public A3Object getNearest(Vector3d v,int scene);
+    public A3Object getNearest(double x,double y,double z,int scene);
+    public A3Object getNearest(Vector3d v,Class<? extends A3Object> c,int scene);
+    public A3Object getNearest(double x,double y,double z,Class<? extends A3Object> c,int scene);
+    public ArrayList<A3Object> getNeighborhood(Vector3d v,double r,int scene);
+    public ArrayList<A3Object> getNeighborhood(double x,double y,double z,double r,int scene);
+    public ArrayList<A3Object> getNeighborhood(Vector3d v,double r,Class<? extends A3Object> c,int scene);
+    public ArrayList<A3Object> getNeighborhood(double x,double y,double z,double r,Class<? extends A3Object> c,int scene);
+    public ArrayList<A3Object> getObjectsInFrustum(Frustum f,int scene);
+    public ArrayList<A3Object> getObjectsInFrustum(Frustum f,,Class<? extends A3Object> c,int scene);
+    */
+    /**
+     * カメラの位置を指定します。自動的に補完が働き滑らかにカメラの位置が
+     * 変ります。
+     */
+    public void setCameraLoc(A3Object a);
+    /**
+     * カメラの回転を指定します。自動的に補完が働き滑らかにカメラの回転が
+     * 変ります。
+     */
+    public void setCameraQuat(A3Object a);
+    /**
+     * カメラの回転を指定します(オイラー角をデグリーで指定:x,y,z版)。
+     * 自動的に補完が働き滑らかにカメラの回転が変ります。
+     */
+    public void setCameraRev(A3Object a);
+    /**
+     * カメラの拡大率を指定します。自動的に補完が働き滑らかにカメラの拡大率が
+     * 変ります。拡大率がデフォルトの1.0の時は10cmより手前と100mより奥はクリッピングされて
+     * 表示されません。拡大率を0.1にすれば1cmから10mの間を表示できるようになり、
+     * 10.0にすれば1mから1kmの間を表示できるようになります。
+     */
+    public void setCameraScale(A3Object a);
+    /**
+     * カメラの位置，回転，拡大率を同時に指定します。
+     * 自動的に補完が働き滑らかに変ります。
+     * 拡大率がデフォルトの1.0の時は10cmより手前と100mより奥はクリッピングされて
+     * 表示されません。拡大率を0.1にすれば1cmから10mの間を表示できるようになり、
+     * 10.0にすれば1mから1kmの間を表示できるようになります。
+     */
+    public void setCameraLocRevScale(A3Object a);
+    //
+    /**
+     * カメラの位置を即時に指定します。
+     */
+    public void setCameraLocNow(A3Object a);
+    /**
+     * カメラの回転を即時に指定します。
+     */
+    public void setCameraQuatNow(A3Object a);
+    /**
+     * カメラの回転を即時に指定します(オイラー角をデグリーで指定)。
+     */
+    public void setCameraRevNow(A3Object a);
+    /**
+     * カメラの拡大率を即時に指定します。拡大率がデフォルトの1.0の時は10cmより
+     * 手前と100mより奥はクリッピングされて表示されません。拡大率を0.1にすれば
+     * 1cmから10mの間を表示できるようになり、10.0にすれば1mから1kmの間を
+     * 表示できるようになります。
+     */
+    public void setCameraScaleNow(A3Object a);
+    /**
+     * カメラの位置，回転，拡大率を同時に即時に指定します。
+     * 拡大率がデフォルトの1.0の時は10cmより手前と100mより奥はクリッピングされて
+     * 表示されません。拡大率を0.1にすれば1cmから10mの間を表示できるようになり、
+     * 10.0にすれば1mから1kmの間を表示できるようになります。
+     */
+    public void setCameraLocRevScaleNow(A3Object a);
+    //
+    /**
+     * シーンを指定して、カメラの位置を指定します。自動的に補完が働き滑らかにカメラの位置が
+     * 変ります。
+     */
+    public void setCameraLoc(A3Object a,int scene);
+    /**
+     * シーンを指定して、カメラの回転を指定します。自動的に補完が働き滑らかにカメラの回転が
+     * 変ります。
+     */
+    public void setCameraQuat(A3Object a,int scene);
+    /**
+     * シーンを指定して、カメラの回転を指定します(オイラー角をデグリーで指定:x,y,z版)。
+     * 自動的に補完が働き滑らかにカメラの回転が変ります。
+     */
+    public void setCameraRev(A3Object a,int scene);
+    /**
+     * シーンを指定して、カメラの拡大率を指定します。自動的に補完が働き滑らかにカメラの拡大率が
+     * 変ります。拡大率がデフォルトの1.0の時は10cmより手前と100mより奥はクリッピングされて
+     * 表示されません。拡大率を0.1にすれば1cmから10mの間を表示できるようになり、
+     * 10.0にすれば1mから1kmの間を表示できるようになります。
+     */
+    public void setCameraScale(A3Object a,int scene);
+    /**
+     * シーンを指定して、カメラの位置，回転，拡大率を同時に指定します。
+     * 自動的に補完が働き滑らかに変ります。
+     * 拡大率がデフォルトの1.0の時は10cmより手前と100mより奥はクリッピングされて
+     * 表示されません。拡大率を0.1にすれば1cmから10mの間を表示できるようになり、
+     * 10.0にすれば1mから1kmの間を表示できるようになります。
+     */
+    public void setCameraLocRevScale(A3Object a,int scene);
+    //
+    /**
+     * シーンを指定して、カメラの位置を即時に指定します。
+     */
+    public void setCameraLocNow(A3Object a,int scene);
+    /**
+     * シーンを指定して、カメラの回転を即時に指定します。
+     */
+    public void setCameraQuatNow(A3Object a,int scene);
+    /**
+     * シーンを指定して、カメラの回転を即時に指定します(オイラー角をデグリーで指定)。
+     */
+    public void setCameraRevNow(A3Object a,int scene);
+    /**
+     * シーンを指定して、カメラの拡大率を即時に指定します。拡大率がデフォルトの1.0の時は10cmより
+     * 手前と100mより奥はクリッピングされて表示されません。拡大率を0.1にすれば
+     * 1cmから10mの間を表示できるようになり、10.0にすれば1mから1kmの間を
+     * 表示できるようになります。
+     */
+    public void setCameraScaleNow(A3Object a,int scene);
+    /**
+     * シーンを指定して、カメラの位置，回転，拡大率を同時に即時に指定します。
+     * 拡大率がデフォルトの1.0の時は10cmより手前と100mより奥はクリッピングされて
+     * 表示されません。拡大率を0.1にすれば1cmから10mの間を表示できるようになり、
+     * 10.0にすれば1mから1kmの間を表示できるようになります。
+     */
+    public void setCameraLocRevScaleNow(A3Object a,int scene);
 }
