@@ -51,6 +51,8 @@ class ActionBehavior extends Behavior implements Cloneable {
     long epilogueStartTime;//最後のフレーズを開始する時間
     long epilogueEndTime;//最終的にアクションが終了する時間
 
+    double timeD;//現在再生中のモーションの開始からの時間(segnoとかも考慮済みの時間)
+
     public ActionBehavior(Action3D action3d,Action3DData action3DData) {
         a3 = action3d;
         a3Data = action3DData;
@@ -234,7 +236,7 @@ class ActionBehavior extends Behavior implements Cloneable {
             }
 
             //実際に骨を動かす
-            double timeD = ((double)time)/1000.0;
+            timeD = ((double)time)/1000.0;
             Action3DData.Action a = a3Data.actions[actionNo];
             String rootBoneName = a.motion.getRootBone();
             for (String boneName : a.tgMap.keySet()) {
@@ -353,6 +355,10 @@ class ActionBehavior extends Behavior implements Cloneable {
         pauseTime = (long)(1000.0*t);
     }
 
+    public double getTime() {
+        return timeD;
+    }
+
     public void setMode(Motion.Mode m) {
         mode = m;
     }
@@ -374,10 +380,12 @@ class ActionBehavior extends Behavior implements Cloneable {
     String getActionName() {
         return a3Data.actions[actionNo].actionName;
     }
+
+/* GAHA
     String getActionNameFromActionNo(int an) {
         return a3Data.actions[an].actionName;
     }
-
+*/
     int getActionNoFromActionName(String an) {
         return a3Data.getActionNoFromActionName(an);
     }
@@ -404,7 +412,7 @@ class ActionBehavior extends Behavior implements Cloneable {
     }
 
     String getActionName(int i) {
-        return null;//gaha
+        return a3Data.actions[i].actionName;
     }
 
     String getComment() {
@@ -512,6 +520,56 @@ class ActionBehavior extends Behavior implements Cloneable {
             actionNo = ((Integer)action).intValue();
         setMotion(actionNo,motion);
     }
+    Motion getMotion(int actionNo) {
+        return a3Data.actions[actionNo].motion;
+    }
+    Motion getMotion(Serializable action) {
+        int actionNo=0;
+        if (action instanceof String)
+            actionNo = a3Data.getActionNoFromActionName((String)action);
+        if (action instanceof Integer)
+            actionNo = ((Integer)action).intValue();
+        return getMotion(actionNo);
+    }
+    double getActionScale(int actionNo) {
+        return a3Data.actions[actionNo].scale;
+    }
+    double getActionScale(Serializable action) {
+        int actionNo=0;
+        if (action instanceof String)
+            actionNo = a3Data.getActionNoFromActionName((String)action);
+        if (action instanceof Integer)
+            actionNo = ((Integer)action).intValue();
+        return getActionScale(actionNo);
+    }
+    Vector3d getActionOffset(int actionNo) {
+        if (a3Data.actions[actionNo].offsetXYZ == null)
+            return new Vector3d();
+        else
+            return new Vector3d(a3Data.actions[actionNo].offsetXYZ);
+    }
+    Vector3d getActionOffset(Serializable action) {
+        int actionNo=0;
+        if (action instanceof String)
+            actionNo = a3Data.getActionNoFromActionName((String)action);
+        if (action instanceof Integer)
+            actionNo = ((Integer)action).intValue();
+        return getActionOffset(actionNo);
+    }
+    Vector3d getActionRot(int actionNo) {
+        if (a3Data.actions[actionNo].rotationXYZ == null)
+            return new Vector3d();
+        else
+            return new Vector3d(a3Data.actions[actionNo].rotationXYZ);
+    }
+    Vector3d getActionRot(Serializable action) {
+        int actionNo=0;
+        if (action instanceof String)
+            actionNo = a3Data.getActionNoFromActionName((String)action);
+        if (action instanceof Integer)
+            actionNo = ((Integer)action).intValue();
+        return getActionRot(actionNo);
+    }
     void setShape(int actionNo,String boneName,Node shape) {
         a3Data.setShape(actionNo,boneName,shape);
     }
