@@ -16,6 +16,9 @@ import java.util.ArrayList;
  * ために使用することができます．
  */
 public class DummyCanvas implements A3CanvasInterface {
+    public DummyCanvas() {//2019,01/18追加(必要ないかもしれないけど)
+        jp.sourceforge.acerola3d.A23.initA23();
+    }
     public void add(A3Object a) {;}
     public void del(A3Object a) {;}
     public void delAll() {;}
