@@ -9,6 +9,7 @@ import javax.swing.*;
 import javax.vecmath.*;
 import java.io.*;
 import java.awt.*;
+import java.util.ArrayList;
 
 /**
  * A3Objectを表示するためのWindowです。このウィンドウには
@@ -1676,4 +1677,138 @@ public class JA3Window extends JFrame implements A3CanvasInterface {
     public void rollCameraLeftNow(double deg,int scene) {
         canvas.rollCameraLeftNow(deg,scene);
     }
+    //****************************************
+    @Override
+    public void setCameraLookAtPoint(A3Object a) {
+        canvas.setCameraLookAtPoint(a);
+    }
+    @Override
+    public void setCameraLookAtPoint(A3Object a,Vector3d up) {
+        canvas.setCameraLookAtPoint(a,up);
+    }
+    @Override
+    public void setCameraLookAtPoint(A3Object a,int scene) {
+        canvas.setCameraLookAtPoint(a,scene);
+    }
+    @Override
+    public void setCameraLookAtPoint(A3Object a,Vector3d up,int scene) {
+        canvas.setCameraLookAtPoint(a,up,scene);
+    }
+    @Override
+    public void setCameraLookAtPointNow(A3Object a) {
+        canvas.setCameraLookAtPointNow(a);
+    }
+    @Override
+    public void setCameraLookAtPointNow(A3Object a,Vector3d up) {
+        canvas.setCameraLookAtPointNow(a,up);
+    }
+    @Override
+    public void setCameraLookAtPointNow(A3Object a,int scene) {
+        canvas.setCameraLookAtPointNow(a,scene);
+    }
+    @Override
+    public void setCameraLookAtPointNow(A3Object a,Vector3d up,int scene) {
+        canvas.setCameraLookAtPointNow(a,up);
+    }
+    @Override
+    public ArrayList<A3Object> getAll() {
+        return canvas.getAll();
+    }
+    @Override
+    public ArrayList<A3Object> getAll(Class<? extends A3Object> c) {
+        return canvas.getAll(c);
+    }
+    @Override
+    public ArrayList<A3Object> getAll(int scene) {
+        return canvas.getAll(scene);
+    }
+    @Override
+    public ArrayList<A3Object> getAll(Class<? extends A3Object> c,int scene) {
+        return canvas.getAll(c,scene);
+    }
+//-------
+    @Override
+    public void turnCameraTo(double dirX,double dirY,double dirZ) {
+        canvas.turnCameraTo(dirX,dirY,dirZ);
+    }
+    @Override
+    public void turnCameraTo(Vector3d dir) {
+        canvas.turnCameraTo(dir);
+    }
+    @Override
+    public void turnCameraToNow(double dirX,double dirY,double dirZ) {
+        canvas.turnCameraToNow(dirX,dirY,dirZ);
+    }
+    @Override
+    public void turnCameraToNow(Vector3d dir) {
+        canvas.turnCameraToNow(dir);
+    }
+    @Override
+    public void turnCameraTo(double dirX,double dirY,double dirZ,int scene) {
+        canvas.turnCameraTo(dirX,dirY,dirZ,scene);
+    }
+    @Override
+    public void turnCameraTo(Vector3d dir,int scene) {
+        canvas.turnCameraTo(dir,scene);
+    }
+    @Override
+    public void turnCameraToNow(double dirX,double dirY,double dirZ,int scene) {
+        canvas.turnCameraToNow(dirX,dirY,dirZ,scene);
+    }
+    @Override
+    public void turnCameraToNow(Vector3d dir,int scene) {
+        canvas.turnCameraToNow(dir,scene);
+    }
+
+    //2015,12/06: 指定したA3Objectの情報をもとにカメラを
+    //コントロールするメソッド達
+    @Override public void setCameraLoc(A3Object a)
+    {setCameraLoc(a.getLoc());}
+    @Override public void setCameraQuat(A3Object a)
+    {setCameraQuat(a.getQuat());}
+    @Override public void setCameraRev(A3Object a)
+    {setCameraQuat(a.getQuat());}
+    @Override public void setCameraScale(A3Object a)
+    {setCameraScale(a.getScale());}
+    @Override public void setCameraLocRevScale(A3Object a)
+    {setCameraLoc(a.getLoc());
+     setCameraQuat(a.getQuat());
+     setCameraScale(a.getScale());}
+    @Override public void setCameraLocNow(A3Object a)
+    {setCameraLocNow(a.getLoc());}
+    @Override public void setCameraQuatNow(A3Object a)
+    {setCameraQuatNow(a.getQuat());}
+    @Override public void setCameraRevNow(A3Object a)
+    {setCameraQuatNow(a.getQuat());}
+    @Override public void setCameraScaleNow(A3Object a)
+    {setCameraScaleNow(a.getScale());}
+    @Override public void setCameraLocRevScaleNow(A3Object a)
+    {setCameraLocNow(a.getLoc());
+     setCameraQuatNow(a.getQuat());
+     setCameraScaleNow(a.getScale());}
+    @Override public void setCameraLoc(A3Object a,int scene)
+    {setCameraLoc(a.getLoc(),scene);}
+    @Override public void setCameraQuat(A3Object a,int scene)
+    {setCameraQuat(a.getQuat(),scene);}
+    @Override public void setCameraRev(A3Object a,int scene)
+    {setCameraQuat(a.getQuat(),scene);}
+    @Override public void setCameraScale(A3Object a,int scene)
+    {setCameraScale(a.getScale(),scene);}
+    @Override public void setCameraLocRevScale(A3Object a,int scene)
+    {setCameraLoc(a.getLoc(),scene);
+     setCameraQuat(a.getQuat(),scene);
+     setCameraScale(a.getScale(),scene);}
+    @Override public void setCameraLocNow(A3Object a,int scene)
+    {setCameraLocNow(a.getLoc(),scene);}
+    @Override public void setCameraQuatNow(A3Object a,int scene)
+    {setCameraQuatNow(a.getQuat(),scene);}
+    @Override public void setCameraRevNow(A3Object a,int scene)
+    {setCameraQuatNow(a.getQuat(),scene);}
+    @Override public void setCameraScaleNow(A3Object a,int scene)
+    {setCameraScaleNow(a.getScale(),scene);}
+    @Override public void setCameraLocRevScaleNow(A3Object a,int scene)
+    {setCameraLocNow(a.getLoc(),scene);
+     setCameraQuatNow(a.getQuat(),scene);
+     setCameraScaleNow(a.getScale(),scene);}
+
 }
